@@ -1,13 +1,14 @@
 #!perl
+# ABSTRACT: Client for Azure Blob Storage
 
 use strict;
 use warnings;
 use v5.10;
 
 package Net::Azure::StorageClient;
-$Net::Azure::StorageClient::VERSION = '0.5_02'; # TRIAL
+$Net::Azure::StorageClient::VERSION = '0.5_03'; # TRIAL
 
-$Net::Azure::StorageClient::VERSION = '0.502';
+$Net::Azure::StorageClient::VERSION = '0.503';
 use LWP::UserAgent;
 use HTTP::Date qw/ time2str /;
 use URI::QueryParam;
@@ -185,11 +186,11 @@ __END__
 
 =head1 NAME
 
-Net::Azure::StorageClient
+Net::Azure::StorageClient - Client for Azure Blob Storage
 
 =head1 VERSION
 
-version 0.5_02
+version 0.5_03
 
 =head1 SYNOPSIS
 
@@ -258,13 +259,37 @@ Specifying the authorization header and send 'POST' request.
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@fragfest.com.au>
+Junnama Noda <junnama@alfasado.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dean Hamstad.
+This software is copyright (c) 2020 by Junnama Noda.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 CONTRIBUTORS
+
+=for stopwords Alexandr Ciornii Dean Hamstead ksasakims paulbort
+
+=over 4
+
+=item *
+
+Alexandr Ciornii <alexchorny@gmail.com>
+
+=item *
+
+Dean Hamstead <djzort@cpan.org>
+
+=item *
+
+ksasakims <gitsasa@outlook.com>
+
+=item *
+
+paulbort <paulbort@gmail.com>
+
+=back
+
 =cut
