@@ -1,13 +1,14 @@
 #!perl
+# ABSTRACT: Object representing a blob in Azure Blob Storage
 
 use strict;
 use warnings;
 use v5.10;
 
 package Net::Azure::StorageClient::Blob;
-$Net::Azure::StorageClient::Blob::VERSION = '0.5_02'; # TRIAL
+$Net::Azure::StorageClient::Blob::VERSION = '0.5_03'; # TRIAL
 
-$Net::Azure::StorageClient::Blob::VERSION = '0.502';
+$Net::Azure::StorageClient::Blob::VERSION = '0.503';
 use parent qw/Net::Azure::StorageClient/;
 use File::Spec;
 use XML::Simple;
@@ -1132,11 +1133,11 @@ __END__
 
 =head1 NAME
 
-Net::Azure::StorageClient::Blob
+Net::Azure::StorageClient::Blob - Object representing a blob in Azure Blob Storage
 
 =head1 VERSION
 
-version 0.5_02
+version 0.5_03
 
 =head1 SYNOPSIS
 
@@ -1484,11 +1485,11 @@ Net::Azure::StorageClient::Blob - Interface to Windows Azure Blob Service
 
 =head1 AUTHOR
 
-Dean Hamstead <dean@fragfest.com.au>
+Junnama Noda <junnama@alfasado.jp>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dean Hamstad.
+This software is copyright (c) 2020 by Junnama Noda.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
